VirtualEnv Installation — satnogs-db 1.19 documentation

# VirtualEnv Installation

1. Requirements

   You will need python, python-virtualenvwrapper, pip and git

2. Get the source code

   Clone source code from the repository:

       $ git clone https://gitlab.com/librespacefoundation/satnogs/satnogs-db.git
       $ cd satnogs-db

3. Build the environment

   Set up the virtual environment. On first run you should create it and link it to your project path.:

       $ mkvirtualenv satnogs-db -a .

4. Configure settings

   Set your environmental variables:

       $ cp env-dist .env

5. Install frontend dependencies

   Install dependencies with `npm`:

       $ npm install

   Test and copy the newly downlodaded static assets:

       $ ./node_modules/.bin/gulp

6. Run it!

   Activate your python virtual environment:

       $ workon satnogs-db

   Just run it:

       (satnogs-db)$ ./bin/djangoctl.sh develop .

7. Populate database

   Create, setup and populate the database with demo data:

       (satnogs-db)$ ./bin/djangoctl.sh initialize

   Your satnogs-db development instance is available in localhost:8000. Go hack!